@@ -51,9 +51,9 @@ def _get_fft_fluctuations(
     velocities = remove_average(velocities)
 
     # Obtain the FFT of heat release and velocities
-    fft_heat_release, fft_frequencies, _ = get_clean_fft(
+    fft_frequencies, fft_heat_release, _ = get_clean_fft(
         time, heat_release, target_frequency, transient_time)
-    fft_velocities, _, _ = get_clean_fft(
+    _, fft_velocities, _ = get_clean_fft(
         time, velocities, target_frequency, transient_time)
 
     return fft_frequencies, fft_heat_release, fft_velocities
@@ -63,8 +63,7 @@ def step1_diagnostic(time, heat_release, velocities, parameters):
     ''' Perform step 1 diagnostics, namely:
         - A plot of the heat release signal in time
         - A plot of the velocity signals in time
-        - A plot of the fourier frequency spectra for heat release
-          and average velocity
+        - A plot of the fourier frequency spectra for heat release and average velocity
 
         The inputs are:
         - heat_release : contains time and signal of heat release.
@@ -625,11 +624,11 @@ def step3_diagnostic(time, heat_release, velocities, parameters):
 def step4_diagnostic(time, heat_release, velocities, parameters):
     ''' Plot diagnostics to check the quality of the Flame Transfer Function.
         Diagnostic 1: Check the fourier spectrum of heat release and
-         gain * velocity (should be equal at the target frequency).
+        gain * velocity (should be equal at the target frequency).
         Diagnostic 2: Plot temporal signals of heat_release(t) vs
-         gain * velocity (t-delay).
+        gain * velocity (t-delay).
         Diagnostic 3: Phase diagram of heat_release as a function of velocity.
-         Should follow a theoretical curve given by the Flame Transfer Function.
+        Should follow a theoretical curve given by the Flame Transfer Function.
 
         For diagnostics 2 and 3, bandpass filtering can be applied around
         the frequency of interest.'''
