@@ -7,19 +7,30 @@ ROUND_PRECISION = 10
 
 
 def remove_initial_transient(time_array, new_initial_time):
-    ''' Remove a portion "transient_time" of time_array, corresponding to a
-    transient regime.'''
+    """ 
+    *Remove a portion "transient_time" of time_array, corresponding to a
+    transient regime*
+
+    :param time_array
+    :type time_array: array
+    :param new_initial_time
+    :type new_initial_time: float
+
+    :returns:
+        - **new_time_array** - array starting at new_initial_time
+
+
+    """
 
     initial_time = time_array[0]
     end_time = time_array[-1]
 
     # Check that transient_time is consistently defined.
     if new_initial_time >= end_time:
-        print("  -> Invalid new initial time specified with -t / --tinit")
         print((("     New initial time {0:05.4f} is larger than the end time "
                "{1:05.4f} the signal.").format(new_initial_time, end_time)))
         print("     Please check option --tinit. ")
-        sys.exit(-1)
+        raise ValueError("Invalid new initial time specified with -t / --tinit")
     if new_initial_time <= initial_time:
         new_initial_time = initial_time
 
@@ -30,10 +41,25 @@ def remove_initial_transient(time_array, new_initial_time):
 
 
 def define_good_time_array(time_array, frequency, new_initial_time=0.0, trim_end=False):
-    ''' Modify a given time array so that:
-        1) Initial transient regime is removed.
-        2) Truncate signal end so as to have a whole number of periods.
-        3) Use a constant time step (average time step).'''
+    """ 
+    *Modify a given time array so that:
+    1) Initial transient regime is removed.
+    2) Truncate signal end so as to have a whole number of periods.
+    3) Use a constant time step (average time step).*
+
+    :param time_array
+    :type time_array: array
+    :param frequency
+    :type frequency: float
+    :param new_initial_time
+    :type new_initial_time: float
+    :param trim_end: By default, the beginning of the time array is trimmed to have a 
+    whole number of periods. You can choose to trim the end setting this parameter to *True*
+    :type trim_end: bool
+
+    :returns:
+        - **clean_time_array** - rearranged array
+    """
 
     # Remove a portion of initial time specified by user
     new_time_array = remove_initial_transient(time_array, new_initial_time)
@@ -61,8 +87,20 @@ def define_good_time_array(time_array, frequency, new_initial_time=0.0, trim_end
 
 
 def interpolate_signals(time_array, signal_array, ref_time_array):
-    ''' Interpolate a single signal on a reference time array.
-        Interpolation is performed with scipy.interpolate.'''
+    """ 
+    *Interpolate a single signal on a reference time array.
+    Interpolation is performed with scipy.interpolate.*
+
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param ref_time_array
+    :type ref_time_array: array
+    
+    :returns:
+        - **new_signal** - Signal interpolated on ref_time_array
+    """
 
     # Check input dimensions
     _check_input_dimensions(time_array, signal_array)
@@ -83,11 +121,17 @@ def interpolate_signals(time_array, signal_array, ref_time_array):
 
 
 def _check_input_dimensions(time_array, signal_array):
-    ''' Check that time_array and signal_array have the correct dimensions.
+    """
+    *Check that time_array and signal_array have the correct dimensions.
+     - time_array should be 1D.
+     - signal_array can be 1D or 2D but the size of the last dimension
+       should be equal to the size of time_array*
 
-         - time_array should be 1D.
-         - signal_array can be 1D or 2D but the size of the last dimension
-           should be equal to the size of time_array '''
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    """
 
     if time_array.ndim != 1:
         raise ValueError('Time array should be 1-D. '
@@ -109,8 +153,23 @@ def _check_input_dimensions(time_array, signal_array):
 
 
 def get_clean_signals(time_array, signal_array, target_frequency, transient_time=0.0):
-    ''' Truncate signals to get a whole number of periods of the target
-        frequency.'''
+    """ 
+    *Truncate signals to get a whole number of periods of the target
+    frequency.*
+    
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param target_frequency
+    :type target_frequency: float
+    :param transient_time
+    :type transient_time: float
+
+    :returns:
+        - **clean_time_array** - Time array capturing a full number of periods according to the target_frequency
+        - **clean_signal_array** - Signal interpolated on clean_time_array
+    """
 
     # Check the dimensions of the inputs
     _check_input_dimensions(time_array, signal_array)
@@ -127,13 +186,27 @@ def get_clean_signals(time_array, signal_array, target_frequency, transient_time
 
 def get_clean_fft(time_array, signal_array,
                   target_frequency, transient_time=0.0):
-    ''' Perform a clean Fast Fourier Transformation.
+    """ 
+    *Perform a clean Fast Fourier Transformation.
+    Special care is taken of the time array to ensure a good definition of
+    the Fourier Coefficient at the target_frequency.
+    All input signals must have the same length and be defined
+    on time_array.*
 
-        Special care is taken of the time array to ensure a good definition of
-        the Fourier Coefficient at the target_frequency.
-
-        All input signals must have the same length and be defined
-        on time_array.'''
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param target_frequency
+    :type target_frequency: float
+    :param transient_time
+    :type transient_time: float
+    
+    :returns:
+        - **fft_frequencies** - Array of fequencies
+        - **fft_spectrum** - Array of fourier amplitudes
+        - **index_target** - Integer, position of the value of the spectrum amplitude at the target frequency
+    """
 
     clean_time_array, clean_signal_array = get_clean_signals(time_array,
                                                              signal_array,
@@ -167,16 +240,29 @@ def get_clean_fft(time_array, signal_array,
     index_target = int(round(target_frequency * nb_samples * time_step, ROUND_PRECISION))
     # Not very satisfied with this... Should probably move this elsewhere
 
-    return fft_spectrum, fft_frequencies, index_target
+    return fft_frequencies, fft_spectrum, index_target
 
 
 def get_coeff_fourier(time_array, signal_array,
                       target_frequency, transient_time=0.0):
-    ''' Computes the Discrete Fourier Coefficient at a single target frequency.
-    '''
+    """ 
+    *Computes the Discrete Fourier Coefficient at a single target frequency.*
+
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param target_frequency
+    :type target_frequency: float
+    :param transient_time
+    :type transient_time: float
+    
+    :returns:
+        - **fourier_coefficient** - Array of the spectrum amplitude(s) at the target frequency
+    """
 
     # Compute complete FFT (might be uselessly long for large arrays...)
-    fft_spectrum, _, index_target = get_clean_fft(
+    _, fft_spectrum, index_target = get_clean_fft(
         time_array, signal_array, target_frequency, transient_time)
 
     # Isolate the Fourier coefficient at target_frequency
@@ -190,8 +276,22 @@ def get_coeff_fourier(time_array, signal_array,
 
 def get_clean_average(time_array, signal_array,
                       target_frequency, transient_time=0.0):
-    ''' Computes the average over a clean time array '''
-    fft_spectrum, _, _ = get_clean_fft(
+    """ 
+    *Computes the average over a clean time array*
+    
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param target_frequency
+    :type target_frequency: float
+    :param transient_time
+    :type transient_time: float
+    
+    :returns:
+        - **average** - Float (or array), average(s) of the initial signal(s)
+    """
+    _, fft_spectrum, _ = get_clean_fft(
         time_array, signal_array, target_frequency, transient_time)
     if fft_spectrum.ndim == 1:
         average = np.abs(fft_spectrum[0])
@@ -202,9 +302,17 @@ def get_clean_average(time_array, signal_array,
 
 
 def remove_average(signal):
-    ''' Remove temporal average from numpy array signal.
-         This array can be multi-dimensional and averaging is
-         performed over the last dimension.'''
+    """ 
+    *Remove temporal average from numpy array signal.
+    This array can be multi-dimensional and averaging is
+    performed over the last dimension. Make sure the signal is clean (dt is constant)*
+    
+    :param signal
+    :type signal: array
+
+    :returns:
+        - **new_signal** - Array, signal with the average taken out
+    """
 
     new_signal = signal - signal.mean(axis=-1, keepdims=True)
 
@@ -214,11 +322,32 @@ def remove_average(signal):
 def get_clean_psd(time_array, signal_array,
                   target_frequency, transient_time=0.0,
                   nb_blocks=1, window_func="flat", overlap_pct=0.0):
-    ''' Compute a clean Power Spectral Density with a time_array trimmed to
-         suit target_frequency.
-         
-         Equivalent to matplotlib.mlab.psd with NFFT = number of samples and no
-         windowing.'''
+    """ 
+    *Compute a clean Power Spectral Density with a time_array trimmed to
+    suit target_frequency.
+    Equivalent to matplotlib.mlab.psd with NFFT = number of samples and no
+    windowing.*
+    
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param target_frequency
+    :type target_frequency: float
+    :param transient_time
+    :type transient_time: float
+    :param nb_blocks
+    :type nb_blocks: int
+    :param window_func
+    :type window_func: string
+    :param overlap_pct
+    :type overlap_pct: float
+
+    :returns: 
+        - **fft_frequencies** - Array of frequencies of the PSD
+        - **psd_spectrum** - Array of values of the PSD spectrum
+        - **index_target** - Integer, position of the target frequency in fft_frequencies and psd_spectrum
+    """
 
     try:
         import matplotlib.mlab as mlab
@@ -262,7 +391,7 @@ def get_clean_psd(time_array, signal_array,
     except ImportError:
         print("matplotlib.mlab package is not available.")
         print("PSD is computed with no windowing.")
-        fft_spectrum, fft_frequencies, index_target = get_clean_fft(
+        fft_frequencies, fft_spectrum, index_target = get_clean_fft(
             time_array, signal_array, target_frequency, transient_time)
 
         frequency_resolution = fft_frequencies[1] - fft_frequencies[0]
@@ -275,7 +404,7 @@ def get_clean_psd(time_array, signal_array,
             psd_spectrum[:, 0] *= 2.
 
     except ValueError:
-        fft_spectrum, fft_frequencies, index_target = get_clean_fft(
+        fft_frequencies, fft_spectrum, index_target = get_clean_fft(
             time_array, signal_array, target_frequency, transient_time)
 
         frequency_resolution = fft_frequencies[1] - fft_frequencies[0]
@@ -287,18 +416,44 @@ def get_clean_psd(time_array, signal_array,
         else:
             psd_spectrum[:, 0] *= 2.
 
-    return psd_spectrum, fft_frequencies, index_target
+    return fft_frequencies, psd_spectrum, index_target
 
 
 def get_average_psd(time, signals, target_frequency, transient_time, discardphase=False, nb_blocks=1,
                     window_func="flat", overlap=0.0):
-    ''' Compute the average PSD of several signals and check the Parseval equality.
-        Two options are possible: with/ without Fourier phases. '''
+    """ 
+    *Compute the average PSD of several signals and check the Parseval equality.
+    Two options are possible: with/ without Fourier phases.*
+    
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param target_frequency
+    :type target_frequency: float
+    :param transient_time
+    :type transient_time: float
+    :param discradphase
+    :type discardphase: bool
+    :param nb_blocks
+    :type nb_blocks: int
+    :param window_func
+    :type window_func: string
+    :param overlap
+    :type overlap: float
+
+    :returns:
+        - **psd_average** -
+        - **psd_freqs** -
+        - **index_target** -
+        - **energy_time** -
+        - **energy_freq** -
+    """
     timestep = time[1] - time[0]
     nb_samples = len(time)
 
     if discardphase:
-        psd_all, psd_freqs, index_target = get_clean_psd(time, signals, target_frequency, transient_time,
+        psd_freqs, psd_all, index_target = get_clean_psd(time, signals, target_frequency, transient_time,
                                                          nb_blocks, window_func, overlap)
         psd_average = np.average(psd_all, axis=0)  # Average over all probes
         energy_time = np.sum(signals ** 2, axis=-1) / nb_samples
@@ -318,11 +473,16 @@ def get_average_psd(time, signals, target_frequency, transient_time, discardphas
 
 def apply_butter_bandpass_filter(time_array, signal_array, low_frequency,
                                  high_frequency, order=3):
-    ''' Apply bandpass filtering with a Butterworth filter. '''
+    """ 
+    *Apply bandpass filtering with a Butterworth filter.*
+
+    """
 
     def _get_butter_bandpass_parameters(
             low_frequency, high_frequency, sampling_frequency, order=5):
-        ''' Define the parameters of the Butterworth bandpass filter '''
+        """ 
+        *Define the parameters of the Butterworth bandpass filter*
+        """
         nyquist_frequency = 0.5 * sampling_frequency
         frequency_limits = [low_frequency / nyquist_frequency,
                             high_frequency / nyquist_frequency]
@@ -348,10 +508,25 @@ def apply_butter_bandpass_filter(time_array, signal_array, low_frequency,
     return filtered_signal
 
 
-def compute_cumulative_fourier(
-        time, signals, target_frequency, transient_time):
-    ''' Compute moving Fourier Coefficient at the target frequency,
-         for a set of signals '''
+def compute_cumulative_fourier(time_array, signal_array, target_frequency, 
+                               transient_time=0.0):
+    """
+    *Compute moving Fourier Coefficient at the target frequency,
+    for a set of signals*
+    
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param target_frequency
+    :type target_frequency: float
+    :param transient_time
+    :type transient_time: float
+
+    :returns:
+        - **cumul_fourier** - Cumulative fourier coefficient over increasing number of periods
+        - **nb_of_periods** - Cumulative number of periods
+    """
 
     time, signals = get_clean_signals(time, signals, target_frequency, transient_time)
     total_time = time[-1] + time[1] - 2 * time[0]
@@ -379,13 +554,31 @@ def compute_cumulative_fourier(
     return cumul_fourier_coeffs, np.arange(1, nb_periods + 1, 1)
 
 
-def get_psd_harmonics(time, signal,
-                      target_frequency, transient_time,
-                      nb_blocks=1, window_shape="flat", overlap=0.0):
-    ''' Compute the PSD of signal fluctuations and sort out the
-         contributions of target_frequency, first and second harmonic
-         from noise.
-         TODO : Make sure this can reads multiple signals. '''
+def get_psd_harmonics(time_array, signal_array,
+                      target_frequency, transient_time=0.0,
+                      nb_blocks=1, window_func="flat", overlap=0.0):
+    """ 
+    *Compute the PSD of signal fluctuations and sort out the
+    contributions of target_frequency, first and second harmonic
+    from noise.
+    TODO : Make sure this can read multiple signals.*
+
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param target_frequency
+    :type target_frequency: float
+    :param transient_time
+    :type transient_time: float
+    :param window_func
+    :type window_func: string
+    :param overlap
+    :type overlap: float
+
+    :returns:
+        - **psd_contributions** - Array containing the fraction of the PSD contained in the target frequency, first, second harmony and in the rest of the spectrum respectively
+    """
 
     # Extract fluctuations
     signal = remove_average(signal)
@@ -432,37 +625,51 @@ def get_psd_harmonics(time, signal,
     return psd_contributions
 
 
-def get_cumulative_average(time, signals, target_frequency, transient_time):
-    ''' Compute the cumulative moving average over a series of signals
-         stored as rows of the numpy array "signals".
-         For now, samples set for averaging is increased one sample at
-         a time.
-         TO DO : allow for a different "speed" of moving average. '''
+def get_cumulative_average(time_array, signal_array, target_frequency, transient_time=0.0):
+    """
+    *Compute the cumulative moving average over a series of signals
+    stored as rows of the numpy array "signals".
+    For now, samples set for averaging is increased one sample at
+    a time.
+    TO DO : allow for a different "speed" of moving average.*
+
+    :param time_array
+    :type time_array: array
+    :param signal_array
+    :type signal_array: array
+    :param target_frequency
+    :type target_frequency: float
+    :param transient_time
+    :type transient_time: float
+
+    :returns:
+        - **cumul_average** - Array containing the cumulative average of the signal over an increasing number of periods
+    """
 
     # number of periods
-    total_time = time[-1] + time[1] - 2 * time[0]
+    total_time = time_array[-1] + time_array[1] - 2 * time_array[0]
     nb_periods = int(round(target_frequency * total_time, ROUND_PRECISION))
-    sampling_frequency = 1. / (time[1] - time[0])
+    sampling_frequency = 1. / (time_array[1] - time_array[0])
     samples_per_period = int(round(sampling_frequency / target_frequency, ROUND_PRECISION))
-    start = int(round(max(0.0, transient_time - time[0]) * sampling_frequency, ROUND_PRECISION))
+    start = int(round(max(0.0, transient_time - time_array[0]) * sampling_frequency, ROUND_PRECISION))
 
     timestep_tol = 3
     # Array is going to be truncated to the right size anyway.
-    if signals.ndim == 1:
+    if signal_array.ndim == 1:
         cumul_average = np.zeros(nb_periods)
         for id_period in range(nb_periods):
             end = start + min((id_period + 1) *
-                              samples_per_period + timestep_tol, time.size)
-            cumul_signals = signals[start:end]
+                              samples_per_period + timestep_tol, time_array.size)
+            cumul_signals = signal_array[start:end]
             cumul_average[id_period] = np.mean(cumul_signals)
-    elif signals.ndim > 1:
+    elif signal_array.ndim > 1:
         cumul_average = (
-            np.zeros((signals.shape[0], nb_periods)))
+            np.zeros((signal_array.shape[0], nb_periods)))
         for id_period in range(nb_periods):
             end = min(
                 (id_period + 1) * samples_per_period + timestep_tol,
-                time.size)
-            cumul_signals = signals[
+                time_array.size)
+            cumul_signals = signal_array[
                             :, start:end]
             cumul_average[:, id_period] = np.average(cumul_signals, axis=-1)
 
